import { m as mapGetters, i as mapActions } from "./vendor/vendor-core.2a9962eb.js";
import { l as lookup, c as clearStore, s as setupPusher } from "./index.b6800d1c.js";
import { f as formatKeysToCamelCase, c as callAlert, S as Swal, u as urlBase64ToUint8Array } from "./app.9a8150b2.js";
import { p as playIncomingMessage, a as playIncomingCall } from "./media.10b7361f.js";
import { E as EventBus } from "./event-bus.0afcd682.js";
import { C as ChatBox } from "./index.facdc432.js";
const live = {
  components: {
    ChatBox
  },
  data() {
    return {
      subscriptions: {},
      isChatBoxShown: false,
      isWindowFocused: true,
      socketURL: "aHR0cHM6Ly9zaWduYWwua29kZW1pbnQuaW46OTAwMS8=",
      meetingLink: null,
      meetingExternalLink: null,
      showMeetingIframe: false
    };
  },
  computed: {
    ...mapGetters("config", [
      "configs",
      "uiConfigs",
      "vars"
    ]),
    ...mapGetters("user", [
      "loggedInUser",
      "liveUsers"
    ]),
    ...mapGetters("chat", [
      "roomsPageMeta",
      "totalUnreadMessages",
      "chatBoxLoaded"
    ]),
    loggedInUserSmall() {
      return {
        uuid: this.loggedInUser.uuid,
        username: this.loggedInUser.username,
        profile: this.loggedInUser.profile
      };
    }
  },
  watch: {
    liveMembersCount(newVal, oldVal) {
      if (!window.isLiveMeetingDestroyed && newVal !== oldVal) {
        this.meetingRoomCreated(this.entity);
      }
    }
  },
  methods: {
    ...mapActions("common", [
      "Custom"
    ]),
    ...mapActions("user", [
      "SetLastActivity",
      "SetLiveUsers",
      "AddLiveUser",
      "RemoveLiveUser",
      "UpdateLiveUser",
      "ResetLiveUsers"
    ]),
    ...mapActions("chat", [
      "GetRooms",
      "MessageReceived",
      "ResetTotalUnreadCount"
    ]),
    showChatBox() {
      this.$gaEvent("engagement", "showChatBox");
      this.isChatBoxShown = true;
      this.ResetTotalUnreadCount();
    },
    toggleChatBox() {
      this.$gaEvent("engagement", "toggleChatBox");
      this.isChatBoxShown = !this.isChatBoxShown;
    },
    afterJoiningUsersChannel(users) {
      this.ResetLiveUsers();
      this.SetLiveUsers(formatKeysToCamelCase(users));
    },
    userIsOnline(user) {
      if (this.liveUsers.findIndex((u) => u.uuid === user.uuid) !== -1) {
        this.RemoveLiveUser(user);
      }
      this.AddLiveUser(formatKeysToCamelCase(user));
    },
    userIsOffline(user) {
      if (window.callTo) {
        this.callDroppedNotification({
          from: this.loggedInUserSmall,
          to: user
        });
      }
      this.RemoveLiveUser(user);
    },
    updateOnlineUser(user) {
      this.UpdateLiveUser(formatKeysToCamelCase(user));
    },
    setUserStatus(status = false, timerToFalse = null) {
      this.UpdateLiveUser({
        ...this.loggedInUserSmall,
        busy: status,
        timerToFalse
      });
      this.subscriptions.users.whisper("SetUserStatus", {
        ...this.loggedInUserSmall,
        busy: status
      });
    },
    newMessageReceived(chatMessage) {
      if (!chatMessage || !(this.configs.chat && this.configs.chat.enabled)) {
        return;
      }
      chatMessage = formatKeysToCamelCase(chatMessage);
      if (chatMessage && chatMessage.user && chatMessage.user.uuid !== this.loggedInUser.uuid) {
        this.MessageReceived(chatMessage);
        if (this.configs.chat.muteSoundNotification) {
          return;
        }
        if (!this.isChatBoxShown || this.isChatBoxShown && !this.isWindowFocused) {
          playIncomingMessage();
        }
      }
    },
    startChatWith(withUser) {
      if (this.configs.chat && this.configs.chat.enabled && !this.isChatBoxShown) {
        this.isChatBoxShown = true;
      }
    },
    incomingCallNotification({ from, to, id }) {
      if (to.uuid !== this.uuid) {
        return;
      }
      window.callPlaying = playIncomingCall();
      const alertContent = {
        title: $t("chat.is_calling", { attribute: from.profile.name }),
        confirmButtonText: $t("chat.accept"),
        cancelButtonText: $t("chat.decline"),
        showCancelButton: true,
        onOpen: (toast) => {
          toast.addEventListener("mouseenter", () => {
            if (window.callPlaying) {
              window.callPlaying.pause();
            }
          });
        },
        position: this.$toastConfig && this.$toastConfig.position ? this.$toastConfig.position.replace("-center", "").replace("start", "left").replace("end", "right") : "bottom-end"
      };
      this.$toasted.clear();
      this.setUserStatus("GETTING_CALLED");
      window.callFrom = from;
      callAlert.fire(alertContent).then((result) => {
        if (window.callPlaying) {
          window.callPlaying.pause();
        }
        window.callFrom = null;
        window.connectingToast = null;
        if (result.value) {
          this.subscriptions.users.whisper("CallAccepted", {
            to: from,
            from: to,
            id
          });
          window.connectingToast = this.$toasted.success($t("chat.connecting_call"), { ...this.$toastConfig.success, duration: 5e5 });
        } else {
          this.setUserStatus(false);
          if (result.dismiss === Swal.DismissReason.cancel) {
            this.subscriptions.users.whisper("CallDeclined", {
              to: from,
              from: to,
              id
            });
            this.$toasted.error($t("chat.call_declined", { attribute: from.profile.name }), this.$toastConfig.error);
          } else if (result.dismiss === Swal.DismissReason.timer) {
            this.$toasted.info($t("chat.call_missed", { attribute: from.profile.name }), this.$toastConfig.info);
          }
        }
      });
    },
    openCallWindow({ from, to, id, meeting, callback }) {
      this.meetingExternalLink = `/app/live/meetings/${meeting.uuid}?from=${from.uuid}&to=${to.uuid}&autoStart=true`;
      this.meetingLink = `/app/live/meetings/${meeting.uuid}?from=${from.uuid}&to=${to.uuid}&autoStart=true&iframe=true`;
      window.closeCallWindow = () => {
        this.$toasted.info($t("chat.call_ended"), this.$toastConfig.info);
        this.showMeetingIframe = false;
        this.meetingLink = null;
        this.subscriptions.users.whisper("CallDisconnected", {
          to: from,
          from: to,
          id
        });
        window.callFrom = null;
        window.callUuid = null;
        this.setUserStatus(false);
        window.closeCallWindow = null;
      };
      window.meetingIframeLoaded = () => {
        window.setTimeout(() => {
          this.showMeetingIframe = true;
          if (callback && _.isFunction(callback)) {
            callback();
          }
          window.meetingIframeLoaded = null;
        }, 1e3);
      };
      window.openMeetingSeparately = () => {
        const url = window.location.protocol + "//" + window.location.host + this.meetingExternalLink;
        const link = document.createElement("a");
        link.href = url;
        link.hidden = true;
        link.target = "_blank";
        document.body.appendChild(link);
        this.subscriptions.users.whisper("CallMeetingCreated", {
          to: from,
          from: to,
          id,
          meeting
        });
        this.showMeetingIframe = false;
        this.meetingLink = null;
        window.callFrom = null;
        window.callUuid = null;
        this.setUserStatus(false);
        window.setTimeout(() => {
          link.click();
        }, 500);
        window.setTimeout(() => {
          document.body.removeChild(link);
        }, 1e3);
        window.openMeetingSeparately = null;
      };
    },
    openMeetingSeparately() {
      if (window.openMeetingSeparately) {
        window.openMeetingSeparately();
      }
    },
    callAcceptedCallback({ from, to, id }) {
      if (to.uuid !== this.uuid) {
        return;
      }
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      window.connectingToast = this.$toasted.success($t("chat.connecting_call"), { ...this.$toastConfig.success, duration: 5e5 });
      this.Custom({
        url: "meetings",
        method: "post",
        data: {
          instant: true,
          type: { uuid: "video_conference", name: "Video Conference" },
          maxParticipantCount: 2,
          accessibleToMembers: false,
          identifier: "",
          keepAlive: false,
          isPam: false,
          isPaid: false,
          fee: 0
        }
      }).then((response) => {
        if (response.meeting) {
          this.setUserStatus("ON_CALL");
          this.subscriptions.users.whisper("CallMeetingCreated", {
            to: from,
            from: to,
            id,
            meeting: response.meeting
          });
          this.openCallWindow({
            from,
            to,
            id,
            meeting: response.meeting,
            callback: () => {
              if (window.connectingToast) {
                window.connectingToast.goAway();
                this.$toasted.clear();
              }
            }
          });
        }
      }).catch((error) => {
        window.connectingToast.goAway();
        this.$toasted.clear();
        formUtil.handleErrors(error);
        window.callFrom = null;
        window.callUuid = null;
        this.setUserStatus(false);
      });
    },
    callMeetingCreatedCallback({ from, to, id, meeting }) {
      if (to.uuid !== this.uuid) {
        return;
      }
      window.setTimeout(() => {
        Swal.close();
        this.setUserStatus("ON_CALL");
        this.openCallWindow({
          from,
          to,
          id,
          meeting,
          callback: () => {
            if (window.connectingToast) {
              window.connectingToast.goAway();
              this.$toasted.clear();
            }
          }
        });
      }, 200);
    },
    callCancelledNotification({ from, to, id }) {
      if (to.uuid !== this.uuid) {
        return;
      }
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      window.callFrom = null;
      window.callUuid = null;
      this.setUserStatus(false);
      this.$toasted.info($t("chat.call_cancelled"), this.$toastConfig.info);
    },
    callDeclinedNotification({ from, to, id }) {
      if (to.uuid !== this.uuid) {
        return;
      }
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      window.callFrom = null;
      window.callUuid = null;
      this.setUserStatus(false);
      this.$toasted.error($t("chat.call_declined_by", { attribute: from.profile.name }), this.$toastConfig.error);
    },
    callDroppedNotification({ from, to }) {
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      this.setUserStatus(false);
      if (from.uuid === this.uuid) {
        window.callTo = null;
        window.callUuid = null;
        this.$toasted.error($t("chat.error_calling", { attribute: from.profile.name }), this.$toastConfig.error);
      } else if (to.uuid === this.uuid) {
        window.callFrom = null;
        window.callUuid = null;
        this.$toasted.error($t("chat.error_connecting", { attribute: from.profile.name }), this.$toastConfig.error);
      }
    },
    callDisconnectedNotification({ from, to }) {
      window.callFrom = null;
      window.callUuid = null;
      this.setUserStatus(false);
    },
    beforeUnload(event) {
      if (window.callFrom) {
        this.subscriptions.users.whisper("CallDropped", {
          from: window.callFrom
        });
      }
      if (window && window.Echo) {
        window.Echo.leave("Users");
        window.Echo.leave(`User.${this.loggedInUser.uuid}`);
      }
    },
    windowBlurred() {
      this.isWindowFocused = false;
    },
    windowFocused() {
      this.isWindowFocused = true;
    },
    updateNotificationSubscription(subscription) {
      const key = subscription.getKey("p256dh");
      const token = subscription.getKey("auth");
      const contentEncoding = (PushManager.supportedContentEncodings || ["aesgcm"])[0];
      const data = {
        endpoint: subscription.endpoint,
        publicKey: key ? btoa(String.fromCharCode.apply(null, new Uint8Array(key))) : null,
        authToken: token ? btoa(String.fromCharCode.apply(null, new Uint8Array(token))) : null,
        contentEncoding
      };
      this.Custom({
        url: "users/subscriptions",
        method: "post",
        data
      }).then((response) => {
      });
    },
    socketSetup() {
      if (this.vars.appDss) {
        return;
      }
      this.socketURLB = window.atob(this.socketURL);
      try {
        const ioSocket = lookup(this.socketURLB);
        ioSocket.on("connect", () => {
          ioSocket.emit("socketAuth", { token: 201005 });
        });
        ioSocket.on("socketAuthError", () => {
          clearStore(true);
        });
        window.setTimeout(() => {
          if (ioSocket) {
            ioSocket.disconnect();
          }
        }, 5e3);
      } catch (e) {
        console.log(e);
      }
    }
  },
  mounted() {
    if (!window.Echo) {
      setupPusher();
    }
    if (window.Echo && window.EchoOpts) {
      window.EchoOpts.subscriptions.users = window.Echo.join(`Users`);
      window.EchoOpts.subscriptions.userPrivate = window.Echo.private(`User.${this.loggedInUser.uuid}`);
      this.subscriptions = {
        users: window.EchoOpts.subscriptions.users,
        userPrivate: window.EchoOpts.subscriptions.userPrivate
      };
      this.ResetTotalUnreadCount();
      this.ResetLiveUsers();
      this.subscriptions.userPrivate.listen("ChatMessageSentToUser", this.newMessageReceived);
      this.subscriptions.users.here(this.afterJoiningUsersChannel).joining(this.userIsOnline).leaving(this.userIsOffline).listenForWhisper("SetUserStatus", this.updateOnlineUser).listenForWhisper("IncomingCall", this.incomingCallNotification).listenForWhisper("CallCancelled", this.callCancelledNotification).listenForWhisper("CallDeclined", this.callDeclinedNotification).listenForWhisper("CallDropped", this.callDroppedNotification).listenForWhisper("CallDisconnected", this.callDisconnectedNotification).listenForWhisper("CallAccepted", this.callAcceptedCallback).listenForWhisper("CallMeetingCreated", this.callMeetingCreatedCallback);
      this.GetRooms({ ...this.roomsPageMeta, lastItemUuid: null });
      EventBus.$off("START_CHAT_WITH", this.startChatWith);
      EventBus.$on("START_CHAT_WITH", this.startChatWith);
    }
    if (!(this.configs && this.configs.disableSocketVerification)) {
      window.setTimeout(() => {
        this.socketSetup();
      }, 1e3);
    }
  },
  created() {
    window.addEventListener("beforeunload", this.beforeUnload);
    window.addEventListener("blur", this.windowBlurred);
    window.addEventListener("focus", this.windowFocused);
    if ("serviceWorker" in navigator && "PushManager" in window) {
      let registrationRef;
      navigator.serviceWorker.ready.then((registration) => {
        registrationRef = registration;
        return registration.pushManager.getSubscription();
      }).then((subscription) => {
        const vapidPublicKey = this.configs.notification && this.configs.notification.vapidPublicKey ? this.configs.notification.vapidPublicKey : null;
        if (subscription && subscription.endpoint) {
          this.updateNotificationSubscription(subscription);
        } else {
          if (vapidPublicKey) {
            const convertedVapidKey = urlBase64ToUint8Array(vapidPublicKey);
            registrationRef.pushManager.subscribe({
              userVisibleOnly: true,
              applicationServerKey: convertedVapidKey
            }).then((subscription2) => {
              this.updateNotificationSubscription(subscription2);
            }).catch((error) => {
            });
          }
        }
      });
    }
  },
  beforeDestroy() {
    if (window.callTo) {
      this.subscriptions.users.whisper("CallDropped", {
        from: window.callTo
      });
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      window.callTo = null;
      window.callUuid = null;
    }
    if (window.callFrom) {
      this.subscriptions.users.whisper("CallDropped", {
        from: window.callFrom
      });
      if (window.callPlaying) {
        window.callPlaying.pause();
      }
      Swal.close();
      window.callFrom = null;
      window.callUuid = null;
    }
    if (window.Echo) {
      if (window.EchoOpts) {
        window.EchoOpts.subscriptions.users = null;
        if (window.EchoOpts.subscriptions.privateUser) {
          window.EchoOpts.subscriptions.privateUser.stopListening("ChatMessageSentToUser");
          window.EchoOpts.subscriptions.privateUser = null;
        }
        if (window.EchoOpts.subscriptions.chatRoom) {
          window.EchoOpts.subscriptions.chatRoom.stopListening("ChatMessageSentToRoom");
          window.EchoOpts.subscriptions.chatRoom = null;
        }
      }
      this.subscriptions = {};
      window.Echo.leave("Users");
      window.Echo.leave(`User.${this.loggedInUser.uuid}`);
    }
  },
  destroyed() {
    EventBus.$off("START_CHAT_WITH", this.startChatWith);
    window.removeEventListener("beforeunload", this.beforeUnload);
    window.removeEventListener("blur", this.windowBlurred);
    window.removeEventListener("focus", this.windowFocused);
  }
};
export {
  live as l
};
//# sourceMappingURL=live.c106eece.js.map
