import { E as EventBus } from "./event-bus.0afcd682.js";
import { a as uploadImage, b as removeImage } from "./uploader.39656730.js";
import { m as mapGetters } from "./vendor/vendor-core.2a9962eb.js";
import { n as normalizeComponent } from "./_plugin-vue2_normalizer.7b9a2fe2.js";
const ImageUploader_vue_vue_type_style_index_0_lang = "";
const _sfc_main = {
  name: "image-uploader",
  props: {
    existingImage: {
      type: String,
      default: ""
    },
    existingMedia: {
      type: Object,
      default: null
    },
    placeholder: {
      type: String,
      default: "https://via.placeholder.com/200/e1e2e4/b1b2b4/?text=Upload%20Image"
    },
    url: {
      type: String,
      required: true
    },
    buttonColor: {
      type: String,
      default: "primary"
    },
    actionLabel: {
      type: String,
      default: "global.choose"
    },
    nameLabel: {
      type: String,
      default: "upload.image"
    },
    buttonSize: {
      type: String,
      default: "sm"
    },
    darkBg: {
      type: Boolean,
      default: false
    },
    profile: {
      type: Boolean,
      default: false
    },
    showUploadButton: {
      type: Boolean,
      default: true
    },
    removeButton: {
      type: Boolean,
      default: true
    },
    removeFromServer: {
      type: Boolean,
      default: true
    },
    showProgress: {
      type: Boolean,
      default: true
    },
    size: {
      type: String,
      default: ""
    },
    fieldName: {
      type: String,
      default: "file"
    }
  },
  data() {
    return {
      isLoading: false,
      imageRemoved: false,
      uploadedImage: "",
      imageToUpload: "",
      actionLabelUpdated: "",
      files: []
    };
  },
  computed: {
    ...mapGetters("config", [
      "configs",
      "vars"
    ]),
    imageSource() {
      const image = this.imageToUpload ? this.imageToUpload : this.uploadedImage ? this.uploadedImage : this.existingImage ? this.existingImage : "";
      if (image) {
        return image;
      }
      return this.placeholder;
    },
    computedActionLabel() {
      return this.existingImage || this.uploadedImage ? "global.change" : this.actionLabel;
    },
    showWhileUploading() {
      return this.imageToUpload && this.files[0] && this.files[0].status === "uploading" ? true : false;
    }
  },
  methods: {
    generateImagePreview(e) {
      this.isLoading = true;
      setTimeout(() => {
        const uploadedFiles = this.$refs.file.files;
        const allowedExtensions = /(\.jpg|\.jpeg|\.png|\.gif|\.bmp)$/i;
        for (let i = 0; i < uploadedFiles.length; i++) {
          if (!allowedExtensions.test(uploadedFiles[i].name)) {
            this.isLoading = false;
            this.$toasted.error(this.$t("global.file_not_supported", { attribute: uploadedFiles[i].name.split(".").pop() }), this.$toastConfig.error);
          } else if (this.configs.system && this.configs.system.postMaxSize && uploadedFiles[i].size > this.configs.system.postMaxSize) {
            this.isLoading = false;
            this.$toasted.error(this.$t("global.file_too_large", { attribute: uploadedFiles[i].name }), this.$toastConfig.error);
          } else {
            this.files.push({
              uuid: uuid(),
              file: uploadedFiles[i],
              status: "waiting",
              progress: 0
            });
          }
        }
        if (!this.files.length) {
          this.isLoading = false;
        } else {
          this.createImage(this.files[0].file);
        }
      }, 1e3);
    },
    createImage(file) {
      let reader = new FileReader();
      reader.onload = (e) => {
        this.imageToUpload = e.target.result;
      };
      reader.onerror = (e) => {
        console.error("File could not be read! Code " + e.target.error.code);
      };
      reader.readAsDataURL(file);
      this.isLoading = false;
    },
    cancelUpload() {
      this.files = [];
      this.imageToUpload = "";
    },
    uploadImage() {
      const uploadObj = this.files[0];
      uploadObj.status = "waiting";
      const onUploadProgress = (progressEvent) => {
        uploadObj.progress = Math.round(progressEvent.loaded * 100 / progressEvent.total);
      };
      let formData = new FormData();
      if (this.files[0].file && this.files[0].file.size > this.configs.system.postMaxSize) {
        this.$toasted.error(this.t("upload.file_too_large"), this.$toastConfig.error);
        return;
      }
      formData.append(this.fieldName, this.files[0].file);
      uploadObj.status = "uploading";
      uploadImage({
        url: this.url,
        data: formData
      }, onUploadProgress).then((response) => {
        uploadObj.status = "uploaded";
        delete uploadObj.cancel;
        this.$toasted.success(response.message, this.$toastConfig.success);
        this.imageToUpload = "";
        this.files = [];
        this.uploadedImage = response.image;
        this.$emit("uploaded", response.image);
      }).catch((error) => {
        uploadObj.status = "error";
        this.$emit("error", error);
        formUtil.handleErrors(error);
      });
    },
    removeImage() {
      if (this.removeFromServer) {
        formUtil.confirmAction().then((result) => {
          if (result.value) {
            this.isLoading = true;
            removeImage({
              url: this.url
            }).then((response) => {
              this.$toasted.success(response.message, this.$toastConfig.success);
              this.imageRemoved = true;
              this.uploadedImage = "";
              this.$emit("removed");
              this.isLoading = false;
            }).catch((error) => {
              this.isLoading = false;
              this.formErrors = formUtil.handleErrors(error);
            });
          }
        });
      } else {
        this.imageRemoved = true;
        this.uploadedImage = "";
        this.$emit("removed");
      }
    },
    startUpload() {
      if (this.files.length) {
        this.uploadImage();
      } else {
        this.$emit("noNeed");
      }
    }
  },
  mounted() {
    EventBus.$off("START_UPLOAD", this.startUpload);
    EventBus.$on("START_UPLOAD", this.startUpload);
    EventBus.$off("CANCEL_UPLOAD", this.cancelUpload);
    EventBus.$on("CANCEL_UPLOAD", this.cancelUpload);
    this.uploadButtonText = this.label;
  },
  destroyed() {
    EventBus.$off("START_UPLOAD", this.startUpload);
    EventBus.$off("CANCEL_UPLOAD", this.cancelUpload);
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { class: ["sm-uploader image-uploader", _vm.size] }, [_c("animated-loader", { attrs: { "is-loading": _vm.isLoading || !_vm.showProgress && _vm.showWhileUploading, "loader-color": _vm.vars.loaderColor } }), _vm.showProgress && _vm.showWhileUploading ? _c("div", { staticClass: "progress-ring-wrapper" }, [_c("progress-ring", { attrs: { "value": _vm.files[0].progress, "stroke-color": _vm.vars.loaderColor } })], 1) : _vm._e(), _vm.imageSource ? _c("div", { class: ["image-display-wrapper", { "dark-bg": _vm.darkBg }] }, [_c("div", { class: ["image-display", { "image-profile": _vm.profile }] }, [_vm.imageToUpload ? _c("img", { staticClass: "img-responsive", attrs: { "src": _vm.imageToUpload } }) : _c("img", { staticClass: "img-responsive", attrs: { "src": _vm.imageSource } })]), _vm.imageToUpload ? _c("div", { staticClass: "submit-actions" }, [_c("base-button", { attrs: { "type": "button", "design": "light", "size": _vm.buttonSize }, on: { "click": _vm.cancelUpload } }, [_c("i", { staticClass: "fas fa-times" }), _vm._v(" " + _vm._s(_vm.$t("general.cancel")))]), _vm.showUploadButton ? _c("base-button", { attrs: { "type": "button", "design": "success", "size": _vm.buttonSize }, on: { "click": _vm.uploadImage } }, [_c("i", { staticClass: "fas fa-arrow-circle-right" }), _vm._v(" " + _vm._s(_vm.$t("general.upload")))]) : _c("base-button", { attrs: { "type": "button", "design": _vm.buttonColor, "size": _vm.buttonSize } }, [_c("i", { staticClass: "far fa-image" }), _vm._v(" " + _vm._s(_vm.$t("global.change", { attribute: _vm.$t(_vm.nameLabel) })))])], 1) : _vm._e()]) : _vm._e(), !_vm.imageToUpload ? _c("div", { staticClass: "image-uploader-form" }, [_vm.existingImage && _vm.removeButton ? _c("div", { staticClass: "existing-image-actions" }, [_c("base-button", { attrs: { "type": "button", "design": "danger", "size": _vm.buttonSize }, on: { "click": _vm.removeImage } }, [_c("i", { staticClass: "fas fa-trash" }), _vm._v(" " + _vm._s(_vm.$t("general.remove")))])], 1) : _vm._e(), _c("div", { staticClass: "file-selector" }, [_c("label", { class: `btn btn-${_vm.buttonColor} btn-${_vm.buttonSize}` }, [_c("input", { ref: "file", staticClass: "selector-input", attrs: { "name": "file", "type": "file", "id": "file", "accept": "image/*" }, on: { "change": _vm.generateImagePreview } }), _vm._m(0), _vm._v(" "), _c("span", { staticClass: "button-label" }, [_vm._v(_vm._s(_vm.$t(_vm.computedActionLabel, { attribute: _vm.$t(_vm.nameLabel) })))])])])]) : _vm._e()], 1);
};
var _sfc_staticRenderFns = [function() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", { staticClass: "button-icon" }, [_c("i", { staticClass: "fas fa-upload" })]);
}];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const ImageUploader = __component__.exports;
export {
  ImageUploader as I
};
//# sourceMappingURL=ImageUploader.fa5c4dda.js.map
