import "./app.9a8150b2.js";
const headerButton = function({ label, icon, tooltip, design = { color: "white", size: "md" } }) {
  return {
    label,
    icon,
    tooltip,
    design: design ? design.color || "white" : "white",
    size: design ? design.size || "md" : "md"
  };
};
const headerRouteButton = function(label, icon, route, tooltip = null, design = null, params = {}, query = {}) {
  return {
    ...headerButton({ label, icon, tooltip, design }),
    action: function(router) {
      router.push({ name: route, params, query });
    }
  };
};
const headerPermittedRouteButton = function(label, icon, route, permission, tooltip = null, design = null, params = {}, query = {}) {
  return {
    ...headerRouteButton(label, icon, route, tooltip, design, params, query),
    permissions: [permission]
  };
};
const headerActionButton = function(label, icon, action, tooltip = null, design = null) {
  return {
    ...headerButton({ label, icon, tooltip, design }),
    action
  };
};
const headerEventButton = function(label, icon, eventOpts, tooltip = null, design = null) {
  return headerActionButton(label, icon, (router, eventBus) => {
    eventBus.$emit(eventOpts.event, eventOpts.options);
  }, tooltip, design);
};
const addButton = function(route, permission) {
  return headerPermittedRouteButton($t("general.add_new"), "fas fa-plus", route, permission);
};
const editButton = function(route, permission) {
  return headerPermittedRouteButton($t("general.edit"), "fas fa-edit", route, permission);
};
const filterButton = function() {
  return headerEventButton("", "fas fa-filter", { event: "TOGGLE_FILTER" }, $t("general.filter"));
};
const configButton = function(route, permission) {
  return headerPermittedRouteButton("", "fas fa-cog", route, permission, $t("general.config"));
};
const defaultSortOptions = {
  storeName: "common",
  design: "white"
};
const getSortOptions = function(options = {}, optionsArray = []) {
  return {
    ...defaultSortOptions,
    ...options,
    options: [
      {
        label: $t("general.default"),
        dispatch: {
          sortBy: ""
        }
      },
      ...optionsArray
    ]
  };
};
const headerLink = function({ label, icon }) {
  return {
    label,
    icon
  };
};
const headerRouteLink = function(label, icon, route, params = {}, query = {}) {
  return {
    ...headerLink({ label, icon }),
    to: { name: route, params, query }
  };
};
const headerPermittedRouteLink = function(label, icon, route, permission, params = {}, query = {}) {
  return {
    ...headerRouteLink(label, icon, route, params, query),
    permissions: [permission]
  };
};
const headerActionLink = function(label, icon, action) {
  return {
    ...headerLink({ label, icon }),
    action
  };
};
const headerEventLink = function(label, icon, eventOpts) {
  return headerActionLink(label, icon, (router, eventBus) => {
    eventBus.$emit(eventOpts.event, eventOpts.options);
  });
};
const importOption = function(route, permission) {
  return headerPermittedRouteLink($t("general.import"), "fas fa-file-import", route, permission);
};
const configOption = function(route, permission) {
  return headerPermittedRouteLink($t("general.config"), "fas fa-cog", route, permission);
};
const saveDraftOption = function() {
  return headerEventLink($t("general.save_draft"), "fas fa-file-upload", { event: "SAVE_DRAFT" });
};
const fetchSavedDraftOption = function() {
  return headerEventLink($t("general.fetch_saved_draft"), "fas fa-file-download", { event: "FETCH_SAVED_DRAFT" });
};
const clearSavedDraftOption = function() {
  return headerEventLink($t("general.clear_saved_draft"), "far fa-minus-square", { event: "CLEAR_SAVED_DRAFT" });
};
const printOption = function() {
  return headerEventLink($t("general.print"), "fas fa-print", { event: "EXPORT", options: { type: "print" } });
};
const exportPdfOption = function() {
  return headerEventLink($t("general.export_pdf"), "fas fa-file-pdf", { event: "EXPORT", options: { type: "pdf" } });
};
const exportXlsOption = function() {
  return headerEventLink($t("general.export_xls"), "fas fa-file-excel", { event: "EXPORT", options: { type: "xls" } });
};
const exportCsvOption = function() {
  return headerEventLink($t("general.export_csv"), "fas fa-file-csv", { event: "EXPORT", options: { type: "csv" } });
};
const keyBindings = {
  filter: {
    key_f: { type: "event", emit: "TOGGLE_FILTER" }
  },
  print: {
    key_p: { type: "event", emit: "EXPORT", payload: { type: "print" } }
  },
  export: {
    key_e: { type: "event", emit: "EXPORT", payload: { type: "pdf" } }
  }
};
const commonKeyBindings = {
  ...keyBindings.filter,
  ...keyBindings.print,
  ...keyBindings.export
};
export {
  commonKeyBindings as a,
  addButton as b,
  clearSavedDraftOption as c,
  configButton as d,
  editButton as e,
  fetchSavedDraftOption as f,
  exportPdfOption as g,
  headerEventButton as h,
  filterButton as i,
  importOption as j,
  configOption as k,
  exportCsvOption as l,
  exportXlsOption as m,
  getSortOptions as n,
  headerPermittedRouteButton as o,
  printOption as p,
  headerActionButton as q,
  headerRouteButton as r,
  saveDraftOption as s
};
//# sourceMappingURL=header.a91390e7.js.map
